# RAISING

This repository contains the source code, simulation data, and documentation for the **RAISING**, a two-stage neural network(NN) implementation framework that first performs hyperparameter tuning to devise the best NN architecture and then performs training on the entire data to estimate the feature importance. The method has been published in Nucleic Acids Research (<https://doi.org/10.1093/nar/gkae1027>).

## RAISING installation

Create a conda environment to install the RAISING

```
conda create -n RAISING_env python=3.9
conda activate RAISING_env
```

Install the package through a github repository

```
pip install git+https://github.com/Devashish13/RAISING.git
```

## RAISING implementation 
Please visit the following link for detailed description of RAISING documentation and tutorials

<https://devashish13.github.io/RAISING/>

## Simulated data generated for detecting polygenic adaptation
Simulated data generated in this study for detecting polygenic selection can be accessed from zenodo repository(<https://zenodo.org/records/12752105>)
